@@ -51,12 +51,13 @@ Introduced in version 0.03, published on January 14, 2005.
 Duplicates removed in version 0.15, published on March 28, 2005.
 
 List entirely updated in version 0.59, published on January 30, 2006.
-
 (Flavio Poletti told me that a few onomatopoeias were missing. I didn't
 add them, but made the list updatable from the original list URL.
 I had to cut two items that were more than 251 character long, so that
 list items are still valid Perl identifiers.)
 
+Updated from the online list in version 0.84, published on July 24, 2006.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -163,6 +164,7 @@ BROOM_GROOM_BROOM
 BROOM_PUCKA_PUCKA_PUCKA_BROOM_PUCKA_PUCKA
 BRRRAPP
 BRRRNNG_BRRRNNG
+BUKKIDA_BUKKIDA_BAKKIDA_BAKKIDA_BUKKIDA_BUKKIDA_BAKKIDA_BAKKIDA
 BUR_RP
 BWAUGHK
 BWEEP
@@ -260,6 +262,7 @@ DOOBA_DOOBA_DEEBE_DEEBE_DOOBA_DOOBA_DEEBE_DEEBE_DOOBA_DOOBA_DEEBE_DEEBE_DOOBA_DO
 DOOBADOOBADOOBA
 DOODLE
 DOONT
+doont
 DOOOT
 doop
 DOOT
@@ -313,6 +316,7 @@ FLIP
 FLIP_BLAP_BLAP
 FLIT
 FLOBA_DAP
+FLOIDOIP
 floof
 FLOOF
 FLOOF_FLOOF
@@ -324,6 +328,7 @@ FLOPLOPLOPLOP
 FLORK
 FLOT
 FLUK_GROON_GROON_GROON_GROON_SPLAZITCH_SPLAZATCH
+FOINSAPP
 FOOF
 FOOM
 FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING_FOOM_FWEE_BOOM_DOOM_DING
@@ -386,6 +391,7 @@ GASHKLITZKA
 GA_SHKLURTZ
 GASHKUTZGA
 GASHOOK_GRUNCH
+GA_SHPLUCT
 GASHPLUTZGA
 GASKROOCH
 GA_SPLORTCH
@@ -410,14 +416,17 @@ GLIK_GLIK_GLIK_GLIK
 GLIKA_GLIKA
 GLiNK
 GLINK
+glinK
 GLINK_PLINK_GLUNK_DINK
 GLIP_SHPIKKLE_GLUP_GAPLORK_SHLIPP_SPLOP_GLIT_PLOBBLE_SHLORP_GLOOP_BLOP_SKLOP_SHLURP_PLiPPLE_SLOTCH_SHLOOP
 GLISH_GLUTCH_YAK_AWK_GAROOF_WEEOOOEEEOOO_BLOOMBLOOM_YAGGAK_WHAP_ROWR_GROWR_GURGLE_GLUK
 GLIT
+GLITCH
 GLIT_GLIT_GLIT
 GLIT_GLIT_GLIT_GLIT
 GLIT_GLIT_GLIT_GLIT_GLOYDOIP_GLIT_GLIKITY_GLIT_GLONT
 GLIT_GLORT_BLEEBLE_DURP
+GLIT_GLORT_BLEEBLE_DURP_GLIT_GLORT_BLEEBLE_DURP
 GLOMP_GLUKKLE_SHLIK_SHLORP_GHOMP_GLUNK_GLIK_SHTORK
 GLOOCHLE_GLOOCHLE_GLUTCH
 GLOODLE
@@ -688,6 +697,7 @@ PSSSH
 PUTT
 PWADAK
 PWAM
+PWANG
 PWEEN
 PWOF
 PWOiNG
@@ -766,6 +776,7 @@ SHPLOIP
 SHPOOOSH_HELP_FAGWASSHHHH_HELP_HELP_GLUKKLE_GLUK
 SHPORK
 SHTIK_SHTIK_SHTIK
+SHTOINK
 SHTOINK_SHTOINK_SHTOINK_SHTOINK
 SHUFFLE_SHIFFLE
 SHUKA_SHUKA_SHUKA
@@ -773,6 +784,7 @@ SHWIK_SHWIKA_SHK_SHHHSK_SHASHWIK_SHWIKA_SHWIK_SHASH_SHAK
 SILENCE
 SIT_SIT_SIT
 SITZ_SITTZLE_SIZZOTZ_KRAKLE
+SIZAFITZ
 SIZZLE_SITZ
 SKAPASCH
 SKAPLUNCH
@@ -860,6 +872,7 @@ SPASH
 SPAZAT
 SPAZOOSH_SSSSSSSST
 SPITZ_SPOPPLE_SPATZ
+SPLADAP
 SPLADUNK
 SPLAK
 SPLAP
@@ -869,6 +882,7 @@ SPLAT
 SPLAZOOSH
 SPLISH
 SPLISHIDY_SPLASH_SPLADISH_SPLADISH_SPLISHIDY_SPLASHIDY_SPLAPIDY_SPLIP
+SPLITCH
 SPLOIT
 SPLOOSH
 SPLOP
@@ -901,6 +915,7 @@ SPUTZ_SPITZA_CHUKKUNK_CLUNK
 SPWAKO
 SPWAP
 SPWAPPO
+SPWATCH
 SSAT
 SSLiT
 SSSSSSSS
@@ -954,10 +969,12 @@ THOOF_FOING
 THOOM_THOOM
 THOOMP
 THOO_PAF
+thort
 THOT
 THUBALUP_THUBALUP_THUBALUP
 THUD
 THUGAWUNK
+thuk
 THUMP
 THUMP_THUMP_THUMP_THUMP_THUMP_THUMP
 THUMP_BUMP
