@@ -59,13 +59,13 @@ The_World_is_Not_Enough Die_Another_Day Casino_Royale
 Sean_Connery George_Lazenby Roger_Moore
 Timothy_Dalton Pierce_Brosnan Daniel_Craig
 # names girls
-Ursula_Andress Eunice_Gayson Zena_Marshall Daniela_Bianchi Eunice_Gayson
+Ursula_Andress Zena_Marshall Daniela_Bianchi Eunice_Gayson
 Honor_Blackman Shirley_Eaton Tania_Mallet Claudine_Auger Luciana_Paluzzi
 Molly_Peters Karin_Dor Mie_Hama Akiko_Wakabayashi Jill_St_John Lana_Wood
 Kim_Basinger Barbara_Carrera Diana_Rigg Gloria_Hendry Jane_Seymour
 Madeline_Smith Maud_Adams Britt_Ekland Barbara_Bach Caroline_Munro
 Sue_Vanner Emily_Bolton Lois_Chiles Corine_Clery Carole_Bouquet
-Lynn_Holly_Johnson Cassandra_Harris Maud_Adams Kristina_Wayborn
+Lynn_Holly_Johnson Cassandra_Harris Kristina_Wayborn
 Fiona_Fullerton Grace_Jones Tanya_Roberts Maryam_D_Abo Carey_Lowell
 Talisa_Soto Famke_Janssen Izabella_Dorota_Scorupco Daphne_Deckers
 Teri_Hatcher Cecilie_Thomsen Michelle_Yeoh Maria_Grazia_Cucinotta
