@@ -5,9 +5,9 @@ our @ISA = qw( Acme::MetaSyntactic::List );
 __PACKAGE__->init();
 
 our %Remote = (
-    source  => 'http://www.cpan.org/authors/00whois.xml',
+    source  => 'http://pause.perl.org/pause/query?ACTION=who_is',
     extract => sub {
-        return map { y/-/_/; $_ } $_[0] =~ m!<id>([-\w\d]+)</id>!g;
+        return map { y/-/_/; $_ } $_[0] =~ m! -- (?:<[^>]+>)?([-\w\d]+)<!g;
     }
 );
 
@@ -30,32 +30,6 @@ Philippe "BooK" Bruhat.
 
 Introduced in version 0.89, published on August 28, 2006.
 
-Further updates:
-
-=over 4
-
-=item * version 0.90, published on September 4, 2006
-
-=item * version 0.91, published on September 11, 2006
-
-=item * version 0.92, published on September 18, 2006
-
-=item * version 0.93, published on September 25, 2006
-
-=item * version 0.94, published on October 2, 2006
-
-=item * version 0.95, published on October 9, 2006
-
-=item * version 0.96, published on October 16, 2006
-
-=item * version 0.97, published on October 23, 2006
-
-=item * version 0.98, published on October 30, 2006
-
-=item * version 0.99, published on Novomber 6, 2006.
-
-=back
-
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -82,7 +56,6 @@ AAYARS
 ABALAMA
 ABARCLAY
 ABCDEFGH
-ABE
 ABELEW
 ABELTJE
 ABERGMAN
@@ -95,7 +68,6 @@ ABIGAIL
 ABLUM
 ABOUTOV
 ABREY
-ABREZINS
 ABROSNAN
 ABS
 ABURKE
@@ -109,7 +81,6 @@ ACCARDO
 ACDALTON
 ACESAVER
 ACESTER
-ACG
 ACH
 ACHEN
 ACHOUNG
@@ -156,7 +127,6 @@ AFARIZWAN
 AFERBER
 AFIELDS
 AFINDLAY
-AFN
 AFOXSON
 AFRIKA
 AFRYER
@@ -187,7 +157,6 @@ AHORNBY
 AHOSEY
 AHOYING
 AIDAN
-AIRWAVE
 AIZVORSKI
 AJACKSON
 AJAEKEL
@@ -229,7 +198,6 @@ ALEXMC
 ALEXMV
 ALEXP
 ALEXPRECH
-ALEXS
 ALFALPHA
 ALFIE
 ALFO
@@ -279,13 +247,11 @@ AMRUTA
 AMS
 AMUGNOLO
 AMURREN
-AMV
 AMW
 ANAGHAKK
 ANARION
 ANATRA
 ANBON
-ANBU
 ANDALE
 ANDERS
 ANDK
@@ -314,12 +280,10 @@ ANFI
 ANGUSLEES
 ANGUYEN
 ANH
-ANIAS
 ANIMATOR
 ANIO
 ANK
 ANKITS
-ANNADURAI
 ANNO
 ANONWB
 ANS
@@ -380,7 +344,6 @@ ARTICLE
 ARTO
 ARTURAZ
 ARUNBEAR
-ARUTEIDO
 ARVIEGAS
 ARVINDPR
 ARYEH
@@ -563,13 +526,11 @@ BEPPU
 BERIKV
 BEROV
 BERRY
-BERT
 BETH
 BETTELLI
 BETUL
 BEVANS
 BEWEGEN
-BFAGA
 BFAIST
 BGARBER
 BGIBBY
@@ -613,7 +574,6 @@ BITS
 BIWILLIA
 BJEPS
 BJKUIT
-BJM
 BJOERN
 BJORNARDO
 BJR
@@ -629,7 +589,6 @@ BKRAMER
 BKUHN
 BLABES
 BLACKSTAR
-BLADE
 BLAIR
 BLANTREWI
 BLBLACK
@@ -672,7 +631,6 @@ BOCONNOR
 BODIN
 BOESCH
 BOEWE
-BOGA
 BOLEK
 BONAR
 BONDFOG
@@ -823,7 +781,6 @@ CARTER
 CASIANO
 CASSJ
 CASTLE
-CAT
 CAUSTIN
 CAVANAUGH
 CAVASQUEZ
@@ -899,7 +856,6 @@ CHESTER
 CHEWTOY
 CHGEUER
 CHGOETZE
-CHI
 CHIA
 CHICKS
 CHIPMUNK
@@ -992,7 +948,6 @@ COLINK
 COLINM
 COLINO
 COLLINS
-COLMODE
 COMAND
 CONTEB
 CONVERTER
@@ -1160,7 +1115,6 @@ DAVIDRA
 DAVIDRW
 DAVIEIRA
 DAVOD
-DAVOOD
 DAXELROD
 DAXIM
 DAZJORZ
@@ -1219,7 +1173,6 @@ DEC
 DECAY
 DECIUS
 DEEMON
-DEEPAK
 DEEPAN
 DEEPCREEK
 DEGE
@@ -1269,7 +1222,6 @@ DGREGORY
 DGRIS
 DGSCOPE
 DGUY
-DHA
 DHABLE
 DHAGAN
 DHAGEMAN
@@ -1370,7 +1322,6 @@ DNAD
 DNARAYAN
 DNEIL
 DNORTH
-DNS
 DOCG
 DOCTORMO
 DODGER
@@ -1536,7 +1487,6 @@ EGYPTUS
 EHARTNETT
 EHERSHEY
 EHOOD
-EIDOLON
 EIJABB
 EIKEG
 EILARA
@@ -1549,16 +1499,13 @@ EJS
 EKG
 EKMETT
 ELAGACHE
-ELENAFRIE
 ELEONORA
 ELEPHANT
 ELH
-ELIAS
 ELIJAH
 ELISA
 ELIZABETH
 ELLIOTF
-ELLIOTJS
 ELLIOTT
 ELLIPSE
 ELMAR
@@ -1579,7 +1526,6 @@ ENEGAARD
 ENELL
 ENGELS
 ENGIN
-ENHERING
 ENNO
 ENRYS
 EPSALON
@@ -1733,7 +1679,6 @@ FREESIDE
 FRETT
 FREUND
 FRIDA
-FRIED
 FRIEDBERG
 FRIEDO
 FRIGHETTI
@@ -1746,7 +1691,6 @@ FSPEISER
 FTASSIN
 FTOBIN
 FUJIWARA
-FUKUDA
 FUZZ
 FVANDUN
 FVULTO
@@ -1890,7 +1834,6 @@ GREGARYH
 GREGFAST
 GREGG
 GREGOR
-GREGORY
 GREIZHANG
 GRENDELUK
 GREP
@@ -2031,9 +1974,6 @@ HIKARINE
 HIMAZU
 HIO
 HIRO
-HIROSE
-HIROYUKI
-HIROYUKIM
 HISELDL
 HITHERTO
 HJB
@@ -2129,7 +2069,6 @@ ICKHABOD
 ICRF
 ICY
 ICYDEE
-IDO
 IDORU
 IFLAN
 IFROL
@@ -2165,7 +2104,6 @@ INFOFLEX
 INGHAM
 INGOMACH
 INGY
-INITDOTD
 INSANEART
 INSANIAC
 INSTANTK
@@ -2189,7 +2127,6 @@ ISAACSON
 ISABELLE
 ISHIGAKI
 ISLUE
-ISOYA
 ISTEEL
 ISTERIN
 ITGURU
@@ -2212,7 +2149,6 @@ IZUT
 JAAN
 JABLKO
 JABURO
-JACKB
 JACKS
 JACKSONM
 JACKTAO
@@ -2322,7 +2258,6 @@ JDAVIDB
 JDB
 JDBOYD
 JDELUISE
-JDENNIS
 JDEVLIN
 JDHEDDEN
 JDIEPEN
@@ -2334,10 +2269,8 @@ JDRAGO
 JDUARTER
 JDUNCAN
 JDUTTON
-JDV
 JEAANDER
 JEAGLE
-JEALLEN
 JEAN
 JEB
 JEDWARDS
@@ -2394,7 +2327,6 @@ JFLUHMANN
 JFORGET
 JFREEMAN
 JFRIEDL
-JFROEBE
 JFURNESS
 JGAMBLE
 JGARRISON
@@ -2452,12 +2384,10 @@ JIMT
 JIMW
 JINKEE
 JIRO
-JIRWIN
 JJARVINEN
 JJDG
 JJGREEN
 JJHORNER
-JJMB
 JJOAO
 JJONES
 JJORDAN
@@ -2552,7 +2482,6 @@ JOCHEN
 JOEHIL
 JOEJIANG
 JOELH
-JOENIO
 JOEOFCLEW
 JOEPHAYES
 JOESUF
@@ -2582,7 +2511,6 @@ JONASO
 JONATHAN
 JONB
 JONBJ
-JONBROWN
 JONE
 JONG
 JONIONS
@@ -2632,7 +2560,6 @@ JQUELIN
 JQUILLAN
 JQUINLAN
 JQUIROGA
-JQYAO
 JRAFTERY
 JRED
 JRENNIE
@@ -2703,7 +2630,6 @@ JURL
 JUSTVIT
 JV
 JVANASCO
-JVASILE
 JVB
 JVBSOFT
 JVENIER
@@ -2722,7 +2648,6 @@ JWIEGLEY
 JWILEY
 JWILLIAMS
 JWOODYATT
-JWU
 JXH
 JZAWODNY
 JZUCKER
@@ -2738,20 +2663,16 @@ KAHUNA
 KAIH
 KAILI
 KAKE
-KALEL
-KALELE
 KALIGUS
 KALLEWOOF
 KALNINS
 KALT
 KAMENSKY
 KAMILLO
-KAMO
 KANE
 KANEY
 KANEZENG
 KANNA
-KAORU
 KAPPA
 KARASIK
 KARDEL
@@ -2785,10 +2706,8 @@ KCK
 KCLARK
 KCODY
 KCOWGILL
-KCWU
 KDOULEPOV
 KDOWNEY
-KEISUKE
 KEJOKI
 KELLAN
 KEN
@@ -2809,7 +2728,6 @@ KESTER
 KESZLER
 KETHGEN
 KEVINA
-KEVINFINK
 KEVINJ
 KEVINR
 KEVINRICE
@@ -2842,7 +2760,6 @@ KIOKO
 KIRILL
 KIRSLE
 KIRSTINB
-KISMET
 KITCHEN
 KITDEKAT
 KITE
@@ -2856,7 +2773,6 @@ KJOHNSON
 KJWCODE
 KKRON
 KLBLNGMJ
-KLEINJ
 KLIMKIN
 KLLIN
 KLOHNER
@@ -2940,7 +2856,6 @@ KUDRA
 KULCHENKO
 KULP
 KULTAWAT
-KUMA
 KUNGFUFTR
 KURGAN
 KURIHARA
@@ -2955,7 +2870,6 @@ KWITTMER
 KWMAK
 KWOO
 KWOOLERY
-KXJ
 KYANNY
 KYLED
 KYNAN
@@ -2990,7 +2904,6 @@ LBENDAVID
 LBORGMAN
 LBOTTEL
 LBROCARD
-LCHAVEZ
 LCOWLE
 LDACHARY
 LDOMKE
@@ -3061,8 +2974,6 @@ LMASARA
 LMEYER
 LMJM
 LMOLNAR
-LMUELLER
-LOCAL
 LOCATION
 LOCHMATT
 LODIN
@@ -3081,7 +2992,6 @@ LPALMER
 LPETERS
 LREEVES
 LROCHER
-LSIM
 LSLOAN
 LSTAF
 LTBOOTS
@@ -3120,7 +3030,6 @@ MACDEE
 MACFLY
 MACGYVER
 MACIEJ
-MACKENZIE
 MACKERS
 MADCODER
 MADGHOUL
@@ -3205,7 +3114,6 @@ MARKWIN
 MARMS
 MARNANEL
 MARSHALL
-MARTIAN
 MARTIJN
 MARTIN
 MARTINB
@@ -3218,11 +3126,8 @@ MARTO
 MARTY
 MARTYLOO
 MARTYNOFF
-MARWATK
 MARZOA
-MASAHITO
 MASAHJI
-MASAKI
 MASANORIH
 MASAP
 MASKLIN
@@ -3270,8 +3175,6 @@ MBLYTHE
 MBOECK
 MBRECH
 MBSTE
-MBURNS
-MBUSIK
 MCAFEE
 MCANTONI
 MCARR
@@ -3423,7 +3326,6 @@ MIRROROK
 MISAKA
 MISCHKE
 MISHA
-MISHOO
 MIT
 MITEL
 MITREHC
@@ -3451,9 +3353,7 @@ MJHEWITT
 MJLEEDS
 MJM
 MJP
-MJR
 MJS
-MKAL
 MKENNEDY
 MKHRAPOV
 MKMUELLER
@@ -3516,10 +3416,8 @@ MOPOKE
 MOREGAN
 MORGOTHII
 MORNI
-MORRISNIH
 MORTENF
 MORTY
-MOSSAD
 MOSTAFAVI
 MOTT
 MOUNS
@@ -3596,7 +3494,6 @@ MSS
 MSTEELE
 MSTEVENS
 MSTRAT
-MSTREEK
 MSTROUT
 MSULLIVAN
 MTHOMAS
@@ -3687,14 +3584,11 @@ NETSNAKE
 NETSRAK
 NEVDULL
 NEVES
-NEVETS
 NEXEN
-NEZUMI
 NFMNUNES
 NGEREN
 NGLEDHILL
 NHARALE
-NIBZE
 NICK
 NICKB
 NICKBAKER
@@ -3781,11 +3675,9 @@ OCTO
 ODDFELLOW
 ODEZWART
 ODIGITY
-ODO
 OESI
 OESTERHOL
 OEVANS
-OFER
 OFEYAIKON
 OFUN
 OHRT
@@ -3813,7 +3705,6 @@ OMEGA
 OMKELLOGG
 ONDR
 ONEIROS
-OOGLEK
 OPHIUCI
 OPI
 OPIATE
@@ -3834,7 +3725,6 @@ OSTROM
 OTAKA
 OTAYLOR
 OTISG
-OTTO
 OUBIWANN
 OUEST
 OVID
@@ -3849,7 +3739,6 @@ PAJAS
 PAJOUT
 PALANT
 PANDICH
-PANOLEX
 PAOLO
 PAPILLION
 PARASEW
@@ -3861,7 +3750,6 @@ PARUSSEL
 PARVEZ
 PASHA
 PASKY
-PASP
 PATL
 PATM
 PATRICK
@@ -4021,7 +3909,6 @@ PLAMBERT
 PLANET
 PLANK
 PLATO
-PLEGALL
 PLEXUS
 PLIAM
 PLISCO
@@ -4036,7 +3923,6 @@ PMC
 PMEVZEK
 PMH
 PMICHAUD
-PMINT
 PMISON
 PMKANE
 PMOORE
@@ -4103,7 +3989,6 @@ PTHOMSEN
 PTILL
 PTIMMINS
 PTIMOF
-PTINSLEY
 PTS
 PTULLY
 PUCKERING
@@ -4120,7 +4005,6 @@ PWD
 PWIRDEMO
 PWO
 PYTHIAN
-QIU
 QJZHOU
 QMACRO
 QMIC
@@ -4141,7 +4025,6 @@ RADER
 RADIANT
 RADKOV
 RADOS
-RADPOC
 RAFAEL
 RAGA
 RAGOFF
@@ -4155,7 +4038,6 @@ RAM
 RAMAN
 RAMBALDI
 RAMESH
-RAMGOPAL
 RAMKI
 RANA
 RANDERSON
@@ -4227,7 +4109,6 @@ REGGERS
 REICHERT
 REID
 REITER
-REITMAN
 REITMEIE
 REITTER
 RELAIS
@@ -4246,7 +4127,6 @@ RFOLEY
 RFRANKEL
 RGARCIA
 RGARTON
-RGC
 RGEOFFREY
 RGIBSON
 RGIERSIG
@@ -4284,7 +4164,6 @@ RICKM
 RIFFER
 RIGBYC
 RIIKI
-RIJK
 RIK
 RIOS
 RIPENCC
@@ -4317,7 +4196,6 @@ RKINYON
 RKITOVER
 RKOBES
 RKOWEN
-RKRIMEN
 RKS
 RLANDRUM
 RLATHROP
@@ -4326,7 +4204,6 @@ RLB
 RLBJR
 RLGARRIS
 RLOCKE
-RLUCAS
 RLZWART
 RMALAFAIA
 RMANGI
@@ -4390,7 +4267,6 @@ ROSULEK
 ROTH
 ROUGE
 ROUS
-ROWAA
 ROWLESD
 RPAGITSCH
 RPAUL
@@ -4407,7 +4283,6 @@ RRG
 RRINDELS
 RRS
 RRWO
-RSANDBERG
 RSARAN
 RSAVAGE
 RSCHUPP
@@ -4450,7 +4325,6 @@ RVSUTHERL
 RWAHBY
 RWALKER
 RWENNER
-RWG
 RWKST
 RWMJ
 RWS
@@ -4492,7 +4366,6 @@ SAMV
 SANBEG
 SANDERSON
 SANFACE
-SANJIT
 SANTU
 SAPA
 SAPAPO
@@ -4511,7 +4384,6 @@ SBALA
 SBASHTON
 SBAZZI
 SBECK
-SBEE
 SBERKHOLZ
 SBERRY
 SBHARR
@@ -4589,8 +4461,6 @@ SELKOVJR
 SEMANTICO
 SEMM
 SEN
-SENDU
-SENGER
 SENSEI
 SEPH
 SER
@@ -4606,7 +4476,6 @@ SEZAY
 SFARRELL
 SFI
 SFINK
-SFLEX
 SFRESCHI
 SGEL
 SGMIANO
@@ -4616,7 +4485,6 @@ SGP
 SGRANTZ
 SHADEJON
 SHADINGER
-SHADOVV
 SHADOW
 SHADOWX
 SHANCOCK
@@ -4645,7 +4513,6 @@ SHGUN
 SHIAR
 SHIBLON
 SHIELDS
-SHIGETA
 SHIGIO
 SHIJIALEE
 SHIKONO
@@ -4767,7 +4634,6 @@ SNIPER
 SNKWATT
 SNOWFLY
 SNOWHARE
-SNOYBERG
 SNS
 SOCK
 SOENKE
@@ -4797,7 +4663,6 @@ SPANNRING
 SPARKS
 SPARSONS
 SPATOCS
-SPAULGER
 SPDITNER
 SPECTRUM
 SPEEVES
@@ -4915,7 +4780,6 @@ SUDIP
 SUE
 SUJAI
 SULFERIC
-SULLIVAN
 SULLR
 SUMMER
 SUMPFRALL
@@ -4929,7 +4793,6 @@ SUNTONG
 SUPAPLEX
 SUPCIK
 SURESHG
-SURESHRAM
 SUTCH
 SVANZOEST
 SVENBAUM
@@ -4937,8 +4800,6 @@ SVENH
 SVENTECH
 SVINTO
 SVITENTI
-SVV
-SWAJ
 SWALTERS
 SWAMPFOX
 SWAMPY
@@ -4953,7 +4814,6 @@ SWILLIAM
 SWMCC
 SWMCD
 SWORDSMAN
-SWSLADE
 SYAMAL
 SYMX
 SYNEDRA
@@ -4971,7 +4831,6 @@ TAIY
 TAKASHI
 TAKAYUKI
 TAKEFUMI
-TAKEO
 TAKESAKO
 TAKESHIGE
 TALE
@@ -4999,7 +4858,6 @@ TBOLIOLI
 TBONE
 TBONECA
 TBOUTELL
-TBR
 TBRADFUTE
 TBRAUN
 TBURGESS
@@ -5036,7 +4894,6 @@ TEUN
 TEVERETT
 TEWK
 TEXMEC
-TFJELL
 TFOUCART
 TGROSE
 TGUMMELS
@@ -5049,7 +4906,6 @@ THARDISON
 THARSCH
 THARTMAN
 THEDEVIL
-THHAMON
 THILO
 THINC
 THINCH
@@ -5066,7 +4922,6 @@ THUNDERA
 THUNDERS
 THW
 TIBBS
-TIGERPERL
 TIGRIS
 TILLY
 TIMA
@@ -5169,7 +5024,6 @@ TROXEL
 TROYP
 TRUESDALE
 TRUSTCOM
-TRYM
 TRZ
 TSANDERS
 TSANGTC
@@ -5188,7 +5042,6 @@ TSTANLEY
 TSTAPFF
 TSTOCK
 TSUKAMOTO
-TSUNODA
 TSV
 TTAR
 TTOD
@@ -5275,14 +5128,12 @@ VIDUL
 VIDUR
 VIKRAMVI
 VILA
-VILEDA
 VILJUN
 VINAYSKI
 VIOSCA
 VIPERCODE
 VIPUL
 VIPULG
-VITA
 VITROTH
 VIY
 VIZDOM
@@ -5302,7 +5153,6 @@ VOLKE
 VORSPRUNG
 VPARSEVAL
 VPLA
-VPOROSHIN
 VROOM
 VRUOTTI
 VSANCHEZ
@@ -5327,7 +5177,6 @@ WARDY
 WARMING
 WARREN
 WARRENM
-WARRINGD
 WARTHURT
 WASX
 WATANABE
@@ -5337,10 +5186,8 @@ WAYNE
 WAYNEDAV
 WAYNEM
 WAZZUTEKE
-WBAILEY
 WBAKER
 WBNIV
-WBY
 WCATLAN
 WCOTTAY
 WDH
@@ -5357,7 +5204,6 @@ WEZ
 WFRERICHS
 WGDAVIS
 WHAMMO
-WHITEB
 WHITEOWL
 WHIZDOG
 WHOELSE
@@ -5401,7 +5247,6 @@ WOLF
 WONKO
 WOODY
 WORENKD
-WORM
 WORRALL
 WPMOORE
 WPS
@@ -5500,7 +5345,6 @@ ZAG
 ZAKZ
 ZANGHIHU
 ZAPHAR
-ZAPHER
 ZARQUON
 ZAXO
 ZBODI
@@ -5518,7 +5362,6 @@ ZERODOGG
 ZETA
 ZEV
 ZEYA
-ZGH
 ZHANGXIN
 ZHIRSCH
 ZHOUXIN
@@ -5535,13 +5378,11 @@ ZIYA
 ZKESSIN
 ZLIPTON
 ZMAN
-ZMIJ
 ZOCCAV
 ZOGZAPPER
 ZOHAER
 ZOMBITHRD
 ZOOLEIKA
-ZOOT
 ZOOVY
 ZOWERS
 ZOWIE
